from enum import Enum
from datetime import datetime
from uuid import UUID, uuid4
from pydantic import BaseModel, Field


class MessageRole(str, Enum):
    SYSTEM = "system"
    USER = "user"
    ASSISTANT = "assistant"
    SCHEMA = "schema"


class Provider(Enum):
    ANTHROPIC = "anthropic"
    OPENAI = "openai"


class Author(Enum):
    HUMAN = "human"
    MACHINE = "machine"


class SignedURLContentRequest(BaseModel):
    id: UUID = Field(default_factory=uuid4)
    key: str
    ttl_seconds: int = 3600


class SignedURLContentResponse(BaseModel):
    id: UUID = Field(default_factory=uuid4)
    signed_url: str
    expiration: datetime
    message: str = "Signed URL generated successfully"



from moxn_models.base import NOT_GIVEN, BaseModelWithOptionalFields, NotGivenOr
from moxn_models.core import Message, Prompt, Task
from moxn_models import schema
from moxn_models import exceptions
from moxn_models.telemetry import (
    BaseSpanEventLog,
    BaseSpanLog,
    BaseTelemetryEvent,
    LLMEvent,
    SpanEventLogType,
    SpanKind,
    SpanLogType,
    SpanStatus,
    TelemetryLogResponse,
    TelemetryTransport,
)
from moxn_models import utils

__all__ = [
    "exceptions",
    "utils",
    "schema",
    "Message",
    "Prompt",
    "Task",
    "NOT_GIVEN",
    "NotGivenOr",
    "BaseModelWithOptionalFields",
    "SpanKind",
    "SpanStatus",
    "SpanLogType",
    "SpanEventLogType",
    "BaseTelemetryEvent",
    "BaseSpanLog",
    "BaseSpanEventLog",
    "TelemetryLogResponse",
    "TelemetryTransport",
    "LLMEvent",
]



class MoxnSchemaValidationError(Exception):
    """Raised when a schema fails validation"""

    def __init__(self, prompt_id: str, version_id: str, schema: str, detail: str):
        self.prompt_id = prompt_id
        self.version_id = version_id
        self.schema = schema
        self.detail = detail
        super().__init__(
            f"Schema validation failed for prompt {prompt_id} (version {version_id}): {detail}"
        )


class MoxnCodegenError(Exception):
    """Base class for codegen-related errors"""

    pass
